package entities;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedAttributeNode;
import javax.persistence.NamedEntityGraph;
import javax.persistence.NamedSubgraph;
import javax.persistence.OneToMany;
import javax.persistence.Version;

@Entity
@NamedEntityGraph(name = "cart.graph",
    attributeNodes = {
        @NamedAttributeNode(value = "cartNumber"),
        @NamedAttributeNode(value = "items", subgraph = "items")
    },
    subgraphs = {
        @NamedSubgraph( name = "items", 
            attributeNodes = {
                @NamedAttributeNode("product")
            }
        )
    }
)
public class Cart implements Serializable {
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id = null;
    @Version
    private int version = 0;
    private String cartNumber;
    @OneToMany(mappedBy = "cart", fetch = FetchType.LAZY, cascade=(CascadeType.ALL))
    private Set<OrderItem> items = new HashSet<>();

    // コンストラクタ、アクセサメソッド
    public Cart() {}
    public  Cart(String cartNumber, Set<OrderItem> items){
        this.cartNumber = cartNumber;
        this.items = items;
    }
    public Long getId() {
        return id;
    }
    public void setId(Long id) {
        this.id = id;
    }
    public int getVersion() {
        return version;
    }
    public void setVersion(int version) {
        this.version = version;
    }
    public String getCartNumber() {
        return cartNumber;
    }
    public void setCartNumber(String cartNumber) {
        this.cartNumber = cartNumber;
    }
    public Set<OrderItem> getItems() {
        return items;
    }
    public void setItems(Set<OrderItem> items) {
        this.items = items;
    }
}
